GlThemeColorsDefinitions class

Constructors

GlThemeColorsDefinitions(Color primary, Color background, Color card, Color info, Color grey, Color shadow)

Properties

background Color
getter/setter pair
card Color
getter/setter pair
grey Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info Color
getter/setter pair
primary Color
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadow Color
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited