GuardlineApi class

Constructors

GuardlineApi(String token)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
getter/setter pair

Methods

documentFile(String session, String type, Uint8List data) Future<bool>
documentJson(String session, String data) Future<bool>
documentProofLife(String session, String uuid, String iproovToken) Future<bool>
documentSession(String session, String ip, String device) Future<bool>
documentValidate(String session) Future<bool>
documentValidateFacematch(String session) Future<bool>
invoke(String path, {String body = ''}) Future
licenseKey() Future<AppKey?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(String session) Future<List<String>>
verifyWithType(String session, String type) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

urlApi → const String