ApiClient class

Constructors

ApiClient({required String baseUrl, required String apiKey, required String secret})
const

Properties

apiKey String
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String
final

Methods

enrolPhoto({required String token, required Image image, required PhotoSource source, Map<String, String> additionalOptions = const {}}) Future<String>
enrolPhotoAndGetVerifyToken({AssuranceType assuranceType = AssuranceType.genuinePresenceAssurance, required String userId, required Image image, required PhotoSource source, Map<String, dynamic> additionalOptions = const {}}) Future<String>
getToken({required AssuranceType assuranceType, required ClaimType claimType, required String userId, Map<String, dynamic> additionalOptions = const {}}) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate({required String token, required String userId, Map<String, dynamic> additionalOptions = const {}}) Future<ValidationResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited