ValidationResult class

Constructors

ValidationResult({required bool isPassed, required String token, required Image? image, required String? failureReason})
const
ValidationResult.fromJson(Map<String, dynamic> json)
factory

Properties

failureReason String?
final
hashCode int
The hash code for this object.
no setterinherited
image → Image?
final
isPassed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited