Microblink class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildDateResult(
DateResult? result) → String -
buildResult(
StringResult? result) → String -
buildStringResult(
String? result) → String -
directApiMultiSideScan(
BuildContext context, String sdkLicenseKey, BlinkidFlutter blinkIdPlugin, {required MicroblinkErrorCallback onError, required MicroblinkSuccessCallback onSuccess}) → Future< void> -
getFields(
BlinkIdScanningResult? result) → List< KeyValue> -
performScan(
String sdkLicenseKey, BlinkidFlutter blinkIdPlugin, {required MicroblinkErrorCallback onError, required MicroblinkSuccessCallback onSuccess}) → Future< void>